import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk._jsii
import aws_cdk.aws_cognito_identitypool_alpha._jsii
import constructs._jsii
import projen._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-prototyping-sdk/identity",
    "0.2.11",
    __name__[0:-6],
    "identity@0.2.11.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
